@@ -15,7 +15,7 @@ class ProspectInteractionEventType(Enum):
 @dataclass_json
 @dataclass
 class ProspectInteractionEvent(UserFacingDataType):
-    prospect_interaction_event_campaign_id: str
+    campaign_id: str
     prospect_id: str
     type: ProspectInteractionEventType
     text_reply: Optional[str] = None
